==> csql-0.9.3.zip: csql-0.9.3/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
 
from setuptools import setup, find_packages
 
import csql
 
setup(
 
    name='csql',
    version=csql.__version__,
    packages=find_packages(),
    author="Frederic Aoustin",
    author_email="mydevpython@gmail.com",
    description="console sql",
    long_description="console sql full python use odbc",
    install_requires= ['colorconsole', 'mytools>= 0.0.1', 'pypyodbc', 'xlwt-future'], #on peut preciser une version "colorconsole >= 0.1"
    include_package_data=False, #mettre True si vous avez un fichier manifest.ini
 
    url='http://mypage.com',
 
    # liste des marqueurs disponible sur:https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Programming Language :: Python",
        "Development Status :: 3 - Alpha",
        "License :: OSI Approved",
        "Natural Language :: French",
        "Operating System :: OS Independent",
        "Environment :: Console", 
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.0",
        "Programming Language :: Python :: 3.1",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: PL/SQL",
        "Topic :: Communications",
        "Topic :: Terminals",
    ],
 
 
    # La syntaxe est "nom-de-commande-a-creer = package.module:fonction".
    entry_points = {
        'console_scripts': [
            'csql = csql.csql:load',
        ],
    },
 
)

==> csql-0.9.6.zip: csql-0.9.6/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
 
from setuptools import setup, find_packages
 
import csql
 
setup(
 
    name='csql',
    version=csql.__version__,
    packages=find_packages(),
    author="Frederic Aoustin",
    author_email="mydevpython@gmail.com",
    description="console sql",
    long_description="console sql full python use odbc",
    install_requires= ['colorconsole>=0.6', 'mytools>= 0.0.1', 'pypyodbc>=1.3.0', 'xlwt-future>=0.8.0'], #on peut preciser une version "colorconsole >= 0.1"
    include_package_data=False, #mettre True si vous avez un fichier manifest.ini
 
    url='http://mypage.com',
 
    # liste des marqueurs disponible sur:https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Programming Language :: Python",
        "Development Status :: 3 - Alpha",
        "License :: OSI Approved",
        "Natural Language :: French",
        "Operating System :: OS Independent",
        "Environment :: Console", 
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.0",
        "Programming Language :: Python :: 3.1",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: PL/SQL",
        "Topic :: Communications",
        "Topic :: Terminals",
    ],
 
 
    # La syntaxe est "nom-de-commande-a-creer = package.module:fonction".
    entry_points = {
        'console_scripts': [
            'csql = csql.cmd:load',
        ],
    },
 
)
